==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/seventhsky/ipb/GetTerminalStatusResponse.java <==

package ru.bitel.bgbilling.modules.tv.dyn.seventhsky.ipb;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="customerID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="terminalID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="terminalInfo" type="{http://www.iskratelecom.ru/IPB/}terminalInfo"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customerID",
    "terminalID",
    "terminalInfo"
})
@XmlRootElement(name = "getTerminalStatusResponse")
public class GetTerminalStatusResponse {

    protected int customerID;
    protected int terminalID;
    @XmlElement(required = true)
    protected TerminalInfo terminalInfo;

    /**
     * Gets the value of the customerID property.
     * 
     */
    public int getCustomerID() {
        return customerID;
    }

    /**
     * Sets the value of the customerID property.
     * 
     */
    public void setCustomerID(int value) {
        this.customerID = value;
    }

    /**
     * Gets the value of the terminalID property.
     * 
     */
    public int getTerminalID() {
        return terminalID;
    }

    /**
     * Sets the value of the terminalID property.
     * 
     */
    public void setTerminalID(int value) {
        this.terminalID = value;
    }

    /**
     * Gets the value of the terminalInfo property.
     * 
     * @return
     *     possible object is
     *     {@link TerminalInfo }
     *     
     */
    public TerminalInfo getTerminalInfo() {
        return terminalInfo;
    }

    /**
     * Sets the value of the terminalInfo property.
     * 
     * @param value
     *     allowed object is
     *     {@link TerminalInfo }
     *     
     */
    public void setTerminalInfo(TerminalInfo value) {
        this.terminalInfo = value;
    }

}

==> tv_10.2504-2510170257.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/seventhsky/ipb/GetTerminalStatusResponse.java <==

package ru.bitel.bgbilling.modules.tv.dyn.seventhsky.ipb;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="customerID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="terminalID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="terminalInfo" type="{http://www.iskratelecom.ru/IPB/}terminalInfo"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customerID",
    "terminalID",
    "terminalInfo"
})
@XmlRootElement(name = "getTerminalStatusResponse")
public class GetTerminalStatusResponse {

    protected int customerID;
    protected int terminalID;
    @XmlElement(required = true)
    protected TerminalInfo terminalInfo;

    /**
     * Gets the value of the customerID property.
     * 
     */
    public int getCustomerID() {
        return customerID;
    }

    /**
     * Sets the value of the customerID property.
     * 
     */
    public void setCustomerID(int value) {
        this.customerID = value;
    }

    /**
     * Gets the value of the terminalID property.
     * 
     */
    public int getTerminalID() {
        return terminalID;
    }

    /**
     * Sets the value of the terminalID property.
     * 
     */
    public void setTerminalID(int value) {
        this.terminalID = value;
    }

    /**
     * Gets the value of the terminalInfo property.
     * 
     * @return
     *     possible object is
     *     {@link TerminalInfo }
     *     
     */
    public TerminalInfo getTerminalInfo() {
        return terminalInfo;
    }

    /**
     * Sets the value of the terminalInfo property.
     * 
     * @param value
     *     allowed object is
     *     {@link TerminalInfo }
     *     
     */
    public void setTerminalInfo(TerminalInfo value) {
        this.terminalInfo = value;
    }

}
